Brain atlas for the Power cortical parcellation with 129 regions based on functional network organization of the human brain. Contains 2D polygon geometry for ggseg::geom_brain().

power()

Value

A ggseg.formats::ggseg_atlas object (cortical).

References

Power JD, Cohen AL, Nelson SM, Wig GS, Barnes KA, Church JA, Vogel AC, Laumann TO, Miezin FM, Schlaggar BL, Petersen SE (2011). Functional Network Organization of the Human Brain. Neuron, 72(4):665-678. doi:10.1016/j.neuron.2011.09.006

Examples

power()
#> 
#> ── power ggseg atlas ───────────────────────────────────────────────────────────
#> Type: cortical
#> Regions: 130
#> Hemispheres: left, right
#> Views: inferior, lateral, superior, medial
#> Palette: 
#> Rendering:  ggseg
#>  ggseg3d (vertices)
#> ────────────────────────────────────────────────────────────────────────────────
#>    hemi       region           label
#> 1  left  LH_region_1  lh_LH_region_1
#> 2  left  LH_region_2  lh_LH_region_2
#> 3  left  LH_region_3  lh_LH_region_3
#> 4  left  LH_region_4  lh_LH_region_4
#> 5  left  LH_region_5  lh_LH_region_5
#> 6  left  LH_region_6  lh_LH_region_6
#> 7  left  LH_region_7  lh_LH_region_7
#> 8  left  LH_region_8  lh_LH_region_8
#> 9  left  LH_region_9  lh_LH_region_9
#> 10 left LH_region_10 lh_LH_region_10
#> ... with 120 more rows
plot(power())